@@ -10,9 +10,13 @@ from spid_cie_oidc.onboarding.schemas.authn_requests import (
     AuthenticationRequestCie,
     AuthenticationRequestSpid
 )
+from spid_cie_oidc.onboarding.schemas.authn_response import AuthenticationErrorResponse, AuthenticationErrorResponseCie, AuthenticationResponse, AuthenticationResponseCie
 from spid_cie_oidc.onboarding.schemas.introspection_request import IntrospectionRequest
+from spid_cie_oidc.onboarding.schemas.introspection_response import IntrospectionErrorResponseCie, IntrospectionErrorResponseSpid, IntrospectionResponse
 from spid_cie_oidc.onboarding.schemas.revocation_request import RevocationRequest
+from spid_cie_oidc.onboarding.schemas.revocation_response import RevocationErrorResponse
 from spid_cie_oidc.onboarding.schemas.token_requests import TokenAuthnCodeRequest, TokenRefreshRequest
+from spid_cie_oidc.onboarding.schemas.token_response import TokenErrorResponse, TokenRefreshResponse, TokenResponse
 
 
 OIDCFED_PROVIDER_PROFILES_MEDIA = getattr(
@@ -20,10 +24,12 @@ OIDCFED_PROVIDER_PROFILES_MEDIA = getattr(
     "OIDCFED_PROVIDER_PROFILES_MEDIA",
     {
         "spid": {
-            "logo": "svg/spid-logo-c-lb.svg"
+            "logo": "svg/spid-logo-c-lb.svg",
+            "arc_position": ""
         },
         "cie": {
-            "logo": "images/logo-cie.png"
+            "logo": "svg/logo-cie.svg",
+            "arc_position": "mt-5"
         },
     },
 )
@@ -87,19 +93,35 @@ OIDCFED_PROVIDER_PROFILES = getattr(
     {
         "spid": {
             "authorization_request": AuthenticationRequestSpid,
+            "authorization_response": AuthenticationResponse,
+            "authorization_error_response": AuthenticationErrorResponse,
             "op_metadata": OPMetadataSpid,
             "authorization_code": TokenAuthnCodeRequest,
+            "authorization_code_response": TokenResponse,
             "refresh_token": TokenRefreshRequest,
+            "refresh_token_response": TokenRefreshResponse,
+            "token_error_response": TokenErrorResponse,
             "revocation_request": RevocationRequest,
+            "revocation_response": RevocationErrorResponse,
             "introspection_request" : IntrospectionRequest,
+            "introspection_response" : IntrospectionResponse,
+            "introspection_error_response" : IntrospectionErrorResponseSpid,
         },
         "cie": {
             "authorization_request": AuthenticationRequestCie,
+            "authorization_response": AuthenticationResponseCie,
+            "authorization_error_response": AuthenticationErrorResponseCie,
             "op_metadata": OPMetadataCie,
             "authorization_code": TokenAuthnCodeRequest,
+            "authorization_code_response": TokenResponse,
             "refresh_token": TokenRefreshRequest,
+            "refresh_token_response": TokenRefreshResponse,
+            "token_error_response": TokenErrorResponse,
             "revocation_request": RevocationRequest,
+            "revocation_response": RevocationErrorResponse,
             "introspection_request" : IntrospectionRequest,
+            "introspection_response" : IntrospectionResponse,
+            "introspection_error_response" : IntrospectionErrorResponseCie,
         },
     },
 )
