@@ -1,18 +1,44 @@
 import logging
 
+from djagger.decorators import schema
 from django.http import (
     HttpResponseBadRequest,
     HttpResponseForbidden,
     JsonResponse
 )
+from django.utils.decorators import method_decorator
 from django.views import View
+from django.views.decorators.csrf import csrf_exempt
+from pydantic import BaseModel
 from spid_cie_oidc.provider.exceptions import ValidationException
 from spid_cie_oidc.provider.models import IssuedToken
+from spid_cie_oidc.provider.settings import (
+    OIDCFED_DEFAULT_PROVIDER_PROFILE,
+    OIDCFED_PROVIDER_PROFILES
+)
 
 from . import OpBase
 logger = logging.getLogger(__name__)
 
 
+schema_profile = OIDCFED_PROVIDER_PROFILES[OIDCFED_DEFAULT_PROVIDER_PROFILE]
+
+
+@schema(
+    methods=['GET', 'POST'],
+    post_request_schema = {
+        "application/x-www-form-urlencoded": schema_profile["introspection_request"]
+    },
+    post_response_schema= {
+            "200":schema_profile["introspection_response"],
+            "400":schema_profile["introspection_error_response"],
+    },
+    get_response_schema= {
+            "400": BaseModel
+    },
+    tags = ['Provider']
+)
+@method_decorator(csrf_exempt, name="dispatch")
 class IntrospectionEndpoint(OpBase, View):
     def get(self, request, *args, **kwargs):
         return HttpResponseBadRequest()
@@ -37,7 +63,7 @@ class IntrospectionEndpoint(OpBase, View):
                 },
                 status = 400
             )
-        except Exception:
+        except Exception: # pragma: no cover
             return HttpResponseForbidden()
         required_token = request.POST['token']
         # query con client_id, access token
