@@ -1,6 +1,7 @@
 import json
 import logging
 
+from djagger.decorators import schema
 from django.conf import settings
 from django.contrib.auth import get_user_model, login
 from django.http import HttpResponseRedirect, JsonResponse
@@ -16,6 +17,7 @@ from spid_cie_oidc.entity.jwtse import (
 from spid_cie_oidc.entity.models import FederationEntityConfiguration
 from spid_cie_oidc.entity.settings import HTTPC_PARAMS
 from spid_cie_oidc.relying_party.exceptions import ValidationException
+from spid_cie_oidc.onboarding.schemas.authn_response import AuthenticationResponseCie
 
 from ..models import OidcAuthentication, OidcAuthenticationToken
 from ..oauth2 import *
@@ -32,6 +34,16 @@ from . import SpidCieOidcRp
 logger = logging.getLogger(__name__)
 
 
+@schema(
+    summary="OIDC Relying Party auth code Callback",
+    methods=['GET'],
+    request_schema=AuthenticationResponseCie,
+    external_docs = {
+        "alt_text": "AgID SPID OIDC Guidelines",
+        "url": "https://www.agid.gov.it/it/agenzia/stampa-e-comunicazione/notizie/2021/12/06/openid-connect-spid-adottate-linee-guida"
+    },
+    tags = ['Relying Party']
+)
 class SpidCieOidcRpCallbackView(View, SpidCieOidcRp, OidcUserInfo, OAuth2AuthorizationCodeGrant):
     """
         View which processes an Authorization Response
@@ -117,13 +129,6 @@ class SpidCieOidcRpCallbackView(View, SpidCieOidcRp, OidcUserInfo, OAuth2Authori
             authz = authz.last()
 
         code = request.GET.get("code")
-        if not code:
-            # TODO: verify error message and status
-            context = {
-                "error": "invalid request",
-                "error_description": _("Request MUST contain code"),
-            }
-            return render(request, self.error_template, context, status=400)
 
         authz_token = OidcAuthenticationToken.objects.create(
             authz_request=authz, code=code
@@ -181,7 +186,7 @@ class SpidCieOidcRpCallbackView(View, SpidCieOidcRp, OidcUserInfo, OAuth2Authori
         if not op_ac_jwk or not op_id_jwk:
             # TODO: verify error message and status
             context = {
-                "error": "invalid token",
+                "error": "invalid_token",
                 "error_description": _("Authentication token seems not to be valid."),
             }
             return render(request, self.error_template, context, status=403)
